==> r-mail-1.0.0.zip: r-mail-1.0.0/gestion_boites/supprimer_boite.php <==
<?

session_start ();

if (isset ($supprimer_boite)) {

if (!empty ($supprimer_boite)) {

$serveur="{".$serveur_mail.":$port_connexion"."}";

$connect_imap=@imap_open($serveur,"$login","$password")
or die ('impossible de se connecter au serveur');

if (@imap_deletemailbox ($connect_imap,"{$serveur}$supprimer_boite")===false) {
header ("location: supprimer_boite.php?non=1");
} else {
header ("location: supprimer_boite.php?oui=1");
}
} else {
$dire=1;
}
}

?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<title>R-MAIL V.1.0.0 - Supprimer une bote mail</title>
</head>
<body>
<form>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>
</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
&#160;
</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
</td></tr>
</table>

<br>

<table border=0 width=100%>
<tr><td align=middle>

	<table border=0 width=50% bgcolor="#1FCBCB" cellpadding=5>
	<tr><td>
	
		<table border=0 width=100% bgcolor="#9AC6CB" cellspacing=0>
		<tr><td align=middle>
		Choisissez la bote  supprimer
		<br><br>
		</td></tr>
		
		<tr><td align=middle>
		<select name="supprimer_boite">
		<option value=""></option>

<?

$serveur="{".$serveur_mail.":$port_connexion"."}";

$connect_imap=@imap_open($serveur,"$login","$password")
or die ('impossible de se connecter au serveur');

$boites=imap_listmailbox ($connect_imap, "$serveur", "*");
$compte= count ($boites);

for ($a=0;$a<$compte;$a++) {
$recup=$boites[$a];
$vide="";
$remplace=ereg_replace ($serveur, $vide, $recup);
preg_match_all("/^[^.]+/", $remplace, $enleve_points);

if (count ($enleve_points[0][0])!=0) {

echo "<option value=\"".$enleve_points[0][0]."\">".$enleve_points[0][0]."</option>\n";
}
}

imap_close ($connect_imap);

?>

		</select>
		<br><br>
		</td></tr>
		
		<tr><td align=middle>
		<input type="submit" value="envoi">
		</td></tr>

<?

if (isset ($non)) {
echo "<tr><td>\n<br>\n</td></tr>\n";
echo "<tr><td align=middle>\n";
echo "La suppression n'a pas russi\n";
}

if (isset ($oui)) {
echo "<tr><td>\n<br>\n</td></tr>\n";
echo "<tr><td align=middle>\n";
echo "La suppression a russi\n";
}

if (isset ($dire)) {
echo "<tr><td>\n<br>\n</td></tr>\n";
echo "<tr><td align=middle>\n";
echo "Merci de renseigner le champ\n";
}

?>

		</table>
	
	</td></tr>
	</table>

</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
&#160;
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL V.1.0.0</u></b></font>
</td></tr>
</table>

</form>
</body>
</html>

==> r-mail-1.0.2.zip: r-mail.1.0.2/gestion_boites/supprimer_boite.php <==
<?

session_start ();

if (isset ($_POST ["supprimer_boite"])) {

if (!empty ($_POST ["supprimer_boite"])) {

$serveur="{".$_SESSION ["serveur_mail"].":".$_SESSION ["port_connexion"]."}";

$connect_imap=@imap_open($serveur,$_SESSION ["login"],$_SESSION ["password"])
or die ('impossible de se connecter au serveur');

$sb = $_POST ["supprimer_boite"];
if (@imap_deletemailbox ($connect_imap,"{$serveur}$sb")===false) {
header ("location: supprimer_boite.php?non=1");
} else {
header ("location: supprimer_boite.php?oui=1");
}
} else {
$dire=1;
}
}

include '../langage.php';

?>

<html>
<head>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<title>R-MAIL - <? echo $page_supprimer_boite[$_SESSION ["lang"]][0]; ?></title>
</head>
<body>
<form method=post>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL</u></b></font>
</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
&#160;
</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
</td></tr>
</table>

<br>

<table border=0 width=100%>
<tr><td align=middle>

	<table border=0 width=50% bgcolor="#1FCBCB" cellpadding=5>
	<tr><td>
	
		<table border=0 width=100% bgcolor="#9AC6CB" cellspacing=0>
		<tr><td align=middle>
		<? echo $page_supprimer_boite[$_SESSION ["lang"]][1]; ?>
		<br><br>
		</td></tr>
		
		<tr><td align=middle>
		<select name="supprimer_boite">
		<option value=""></option>

<?

$serveur="{".$_SESSION ["serveur_mail"].":".$_SESSION ["port_connexion"]."}";

$connect_imap=@imap_open($serveur,$_SESSION ["login"],$_SESSION ["password"])
or die ('impossible de se connecter au serveur');

$boites=imap_listmailbox ($connect_imap, "$serveur", "*");
$compte= count ($boites);

for ($a=0;$a<$compte;$a++) {
$recup=$boites[$a];
$vide="";
$remplace=ereg_replace ($serveur, $vide, $recup);
preg_match_all("/^[^.]+/", $remplace, $enleve_points);

if (count ($enleve_points[0][0])!=0) {

echo "<option value=\"".$enleve_points[0][0]."\">".$enleve_points[0][0]."</option>\n";
}
}

imap_close ($connect_imap);

?>

		</select>
		<br><br>
		</td></tr>
		
		<tr><td align=middle>
		<input type="submit" value="<? echo $page_supprimer_boite[$_SESSION ["lang"]][2]; ?>">
		</td></tr>

<?

if (isset ($_GET ["non"])) {
echo "<tr><td>\n<br>\n</td></tr>\n";
echo "<tr><td align=middle>\n";
echo $page_supprimer_boite[$_SESSION ["lang"]][3]."\n";
}

if (isset ($_GET ["oui"])) {
echo "<tr><td>\n<br>\n</td></tr>\n";
echo "<tr><td align=middle>\n";
echo $page_supprimer_boite[$_SESSION ["lang"]][4]."\n";
}

if (isset ($dire)) {
echo "<tr><td>\n<br>\n</td></tr>\n";
echo "<tr><td align=middle>\n";
echo $page_supprimer_boite[$_SESSION ["lang"]][5]."\n";
}

?>

		</table>
	
	</td></tr>
	</table>

</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
</td></tr>
</table>

<br>

<table width=100% bgcolor="#1FCBCB" cellspacing=0>
<tr><td>
&#160;
</td></tr>
</table>

<br>

<table border=0 width=100% cellspacing=0>
<tr><td align=middle bgcolor="#1FCBCB">
<font size=5><b><u>R-MAIL</u></b></font>
</td></tr>
</table>

</form>
</body>
</html>
